# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineProcessorResponse(Model):
    """BaselineProcessorResponse.

    :param include_in_cap: Indicates if the meter will be included in savings
     calculations
    :type include_in_cap: bool
    :param adjust_area: Indicates if floor area adjustments should be made
    :type adjust_area: bool
    :param adjusted_cost_type:
    :type adjusted_cost_type: ~energycap.sdk.models.AdjustedCostTypeResponse
    :param adjust_winter: Indicates if winter weather adjustments should be
     made
    :type adjust_winter: bool
    :param adjust_summer: Indicates if summer weather adjustments should be
     made
    :type adjust_summer: bool
    :param baseline_months: Number of months in the baseline
     Setting this to anything other than 12 will turn off weather adjustments
     irregardless of the settings in adjustWinter and adjustSummer
    :type baseline_months: int
    :param baseline_start_date: Baseline start date
    :type baseline_start_date: datetime
    :param savings_start_date: Savings Period start date
    :type savings_start_date: datetime
    :param use_extended_weather: Indicates if extended weather should be used.
     Extended weather uses additional months prior to the baseline start date
     to determine weather sensitivity.
    :type use_extended_weather: bool
    :param extended_weather_start_date: Start Date of the extended weather.
     This should be 1, 2 or 3 years prior to the baseline start date.
     Extended weather uses additional months prior to the baseline start date
     to determine weather sensitivity.
    :type extended_weather_start_date: datetime
    :param cooling_temp: Cooling balance point
    :type cooling_temp: int
    :param cooling_intercept: Cooling intercept
    :type cooling_intercept: float
    :param cooling_max_degree_days: Cooling max Degree Days
    :type cooling_max_degree_days: float
    :param cooling_max_use: Cooling max use
    :type cooling_max_use: float
    :param cooling_r2: Cooling R2
    :type cooling_r2: float
    :param cooling_min_r2: Cooling minimum R2
    :type cooling_min_r2: float
    :param cooling_calculated_r2: Cooling calculated R2
    :type cooling_calculated_r2: float
    :param cooling_slope: Cooling slope
    :type cooling_slope: float
    :param cooling_std_dev: Cooling standard deviation
    :type cooling_std_dev: float
    :param heating_temp: Heating balance point
    :type heating_temp: int
    :param heating_intercept: Heating intercept
    :type heating_intercept: float
    :param heating_max_degree_days: Heating maximum Degree Days
    :type heating_max_degree_days: float
    :param heating_max_use: Heating maximum use
    :type heating_max_use: float
    :param heating_r2: Heating R2
    :type heating_r2: float
    :param heating_min_r2: Heating minimum R2
    :type heating_min_r2: float
    :param heating_calculated_r2: Heating calculated R2
    :type heating_calculated_r2: float
    :param heating_slope: Heating slope
    :type heating_slope: float
    :param heating_std_dev: Heating standard deviation
    :type heating_std_dev: float
    :param native_use_unit:
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param baseline_bills: Indicates whether or not each bill in the baseline
     should be included in the baseline regression
    :type baseline_bills:
     list[~energycap.sdk.models.BaselineProcessorResponseBaselineBill]
    """

    _attribute_map = {
        'include_in_cap': {'key': 'includeInCAP', 'type': 'bool'},
        'adjust_area': {'key': 'adjustArea', 'type': 'bool'},
        'adjusted_cost_type': {'key': 'adjustedCostType', 'type': 'AdjustedCostTypeResponse'},
        'adjust_winter': {'key': 'adjustWinter', 'type': 'bool'},
        'adjust_summer': {'key': 'adjustSummer', 'type': 'bool'},
        'baseline_months': {'key': 'baselineMonths', 'type': 'int'},
        'baseline_start_date': {'key': 'baselineStartDate', 'type': 'iso-8601'},
        'savings_start_date': {'key': 'savingsStartDate', 'type': 'iso-8601'},
        'use_extended_weather': {'key': 'useExtendedWeather', 'type': 'bool'},
        'extended_weather_start_date': {'key': 'extendedWeatherStartDate', 'type': 'iso-8601'},
        'cooling_temp': {'key': 'coolingTemp', 'type': 'int'},
        'cooling_intercept': {'key': 'coolingIntercept', 'type': 'float'},
        'cooling_max_degree_days': {'key': 'coolingMaxDegreeDays', 'type': 'float'},
        'cooling_max_use': {'key': 'coolingMaxUse', 'type': 'float'},
        'cooling_r2': {'key': 'coolingR2', 'type': 'float'},
        'cooling_min_r2': {'key': 'coolingMinR2', 'type': 'float'},
        'cooling_calculated_r2': {'key': 'coolingCalculatedR2', 'type': 'float'},
        'cooling_slope': {'key': 'coolingSlope', 'type': 'float'},
        'cooling_std_dev': {'key': 'coolingStdDev', 'type': 'float'},
        'heating_temp': {'key': 'heatingTemp', 'type': 'int'},
        'heating_intercept': {'key': 'heatingIntercept', 'type': 'float'},
        'heating_max_degree_days': {'key': 'heatingMaxDegreeDays', 'type': 'float'},
        'heating_max_use': {'key': 'heatingMaxUse', 'type': 'float'},
        'heating_r2': {'key': 'heatingR2', 'type': 'float'},
        'heating_min_r2': {'key': 'heatingMinR2', 'type': 'float'},
        'heating_calculated_r2': {'key': 'heatingCalculatedR2', 'type': 'float'},
        'heating_slope': {'key': 'heatingSlope', 'type': 'float'},
        'heating_std_dev': {'key': 'heatingStdDev', 'type': 'float'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'baseline_bills': {'key': 'baselineBills', 'type': '[BaselineProcessorResponseBaselineBill]'},
    }

    def __init__(self, **kwargs):
        super(BaselineProcessorResponse, self).__init__(**kwargs)
        self.include_in_cap = kwargs.get('include_in_cap', None)
        self.adjust_area = kwargs.get('adjust_area', None)
        self.adjusted_cost_type = kwargs.get('adjusted_cost_type', None)
        self.adjust_winter = kwargs.get('adjust_winter', None)
        self.adjust_summer = kwargs.get('adjust_summer', None)
        self.baseline_months = kwargs.get('baseline_months', None)
        self.baseline_start_date = kwargs.get('baseline_start_date', None)
        self.savings_start_date = kwargs.get('savings_start_date', None)
        self.use_extended_weather = kwargs.get('use_extended_weather', None)
        self.extended_weather_start_date = kwargs.get('extended_weather_start_date', None)
        self.cooling_temp = kwargs.get('cooling_temp', None)
        self.cooling_intercept = kwargs.get('cooling_intercept', None)
        self.cooling_max_degree_days = kwargs.get('cooling_max_degree_days', None)
        self.cooling_max_use = kwargs.get('cooling_max_use', None)
        self.cooling_r2 = kwargs.get('cooling_r2', None)
        self.cooling_min_r2 = kwargs.get('cooling_min_r2', None)
        self.cooling_calculated_r2 = kwargs.get('cooling_calculated_r2', None)
        self.cooling_slope = kwargs.get('cooling_slope', None)
        self.cooling_std_dev = kwargs.get('cooling_std_dev', None)
        self.heating_temp = kwargs.get('heating_temp', None)
        self.heating_intercept = kwargs.get('heating_intercept', None)
        self.heating_max_degree_days = kwargs.get('heating_max_degree_days', None)
        self.heating_max_use = kwargs.get('heating_max_use', None)
        self.heating_r2 = kwargs.get('heating_r2', None)
        self.heating_min_r2 = kwargs.get('heating_min_r2', None)
        self.heating_calculated_r2 = kwargs.get('heating_calculated_r2', None)
        self.heating_slope = kwargs.get('heating_slope', None)
        self.heating_std_dev = kwargs.get('heating_std_dev', None)
        self.native_use_unit = kwargs.get('native_use_unit', None)
        self.baseline_bills = kwargs.get('baseline_bills', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StatisticsResponse(Model):
    """StatisticsResponse.

    :param model: The model value
    :type model: float
    :param difference: The difference between the model and the actual value
    :type difference: float
    :param standard_deviation: Statistical measure of how spread out numbers
     are from the average
    :type standard_deviation: float
    :param variance: Statistical measure of how far each value in the data set
     is from the mean
    :type variance: float
    :param r_squared: Statistical measure of how close the data is to the
     fitted regression line
    :type r_squared: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    :param severity:
    :type severity: ~energycap.sdk.models.OutlierSeverityChild
    """

    _attribute_map = {
        'model': {'key': 'model', 'type': 'float'},
        'difference': {'key': 'difference', 'type': 'float'},
        'standard_deviation': {'key': 'standardDeviation', 'type': 'float'},
        'variance': {'key': 'variance', 'type': 'float'},
        'r_squared': {'key': 'rSquared', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'severity': {'key': 'severity', 'type': 'OutlierSeverityChild'},
    }

    def __init__(self, **kwargs):
        super(StatisticsResponse, self).__init__(**kwargs)
        self.model = kwargs.get('model', None)
        self.difference = kwargs.get('difference', None)
        self.standard_deviation = kwargs.get('standard_deviation', None)
        self.variance = kwargs.get('variance', None)
        self.r_squared = kwargs.get('r_squared', None)
        self.unit = kwargs.get('unit', None)
        self.severity = kwargs.get('severity', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseState(Model):
    """DataAccessReleaseState.

    :param submitted_date: The date that the data access release was
     submitted.
     Null if there is not a release yet.
    :type submitted_date: datetime
    :param release_status:
    :type release_status: ~energycap.sdk.models.DataAccessReleaseStatus
    """

    _attribute_map = {
        'submitted_date': {'key': 'submittedDate', 'type': 'iso-8601'},
        'release_status': {'key': 'releaseStatus', 'type': 'DataAccessReleaseStatus'},
    }

    def __init__(self, *, submitted_date=None, release_status=None, **kwargs) -> None:
        super(DataAccessReleaseState, self).__init__(**kwargs)
        self.submitted_date = submitted_date
        self.release_status = release_status



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagResponse(Model):
    """FlagResponse.

    :param flag_id: The flag identifier
    :type flag_id: int
    :param flag_type:
    :type flag_type: ~energycap.sdk.models.FlagTypeChild
    :param flag_status:
    :type flag_status: ~energycap.sdk.models.FlagStatusChild
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: Date the flag was created
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: Latest date the flag was modified
    :type modified_date: datetime
    :param cost_recovery: Cost recovery associated with the issue this flag
     represents
    :type cost_recovery: float
    :param flag_events: All events and actions that have occurred with this
     flag
    :type flag_events: list[~energycap.sdk.models.FlagEventChild]
    :param assignees: All users currently assigned to this flag
    :type assignees: list[~energycap.sdk.models.UserChild]
    :param flag_issues: All issues associated with the flag
     Even if the flag is marked as resolved, the list of issues that were on
     the flag at that time will remain.
     This keeps a historic record and allows for filtering.
    :type flag_issues: list[~energycap.sdk.models.FlagIssueTypeChild]
    """

    _attribute_map = {
        'flag_id': {'key': 'flagId', 'type': 'int'},
        'flag_type': {'key': 'flagType', 'type': 'FlagTypeChild'},
        'flag_status': {'key': 'flagStatus', 'type': 'FlagStatusChild'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'cost_recovery': {'key': 'costRecovery', 'type': 'float'},
        'flag_events': {'key': 'flagEvents', 'type': '[FlagEventChild]'},
        'assignees': {'key': 'assignees', 'type': '[UserChild]'},
        'flag_issues': {'key': 'flagIssues', 'type': '[FlagIssueTypeChild]'},
    }

    def __init__(self, **kwargs):
        super(FlagResponse, self).__init__(**kwargs)
        self.flag_id = kwargs.get('flag_id', None)
        self.flag_type = kwargs.get('flag_type', None)
        self.flag_status = kwargs.get('flag_status', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_date = kwargs.get('created_date', None)
        self.modified_by = kwargs.get('modified_by', None)
        self.modified_date = kwargs.get('modified_date', None)
        self.cost_recovery = kwargs.get('cost_recovery', None)
        self.flag_events = kwargs.get('flag_events', None)
        self.assignees = kwargs.get('assignees', None)
        self.flag_issues = kwargs.get('flag_issues', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarTaskResponse(Model):
    """EnergyStarTaskResponse.

    :param energy_star_task_id: The task identifier
    :type energy_star_task_id: int
    :param task_type: The task type
    :type task_type: str
    :param begin_date: The date the submission was initiated
    :type begin_date: datetime
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param number_of_places: The number of buildings in the submission
    :type number_of_places: int
    :param submission_task_status: Status for the submission portion of the
     task
    :type submission_task_status: str
    :param metrics_retrieval_task_status: Status for the metrics retrieval
     portion of the task
    :type metrics_retrieval_task_status: str
    :param submission_log_file_name: Filename of the log containing errors
     encountered during submission
     Will be null if this task is only for metrics retrieval or if there were
     no errors during submission
    :type submission_log_file_name: str
    :param metrics_retrieval_log_file_name: Filename of the log containing
     errors or alerts encountered during metrics retrieval
    :type metrics_retrieval_log_file_name: str
    :param submission_type:
    :type submission_type: ~energycap.sdk.models.SubmissionTypeResponse
    :param places: The list of buildings/submission periods in the submission
    :type places: list[~energycap.sdk.models.EnergyStarTaskPlaceChild]
    """

    _attribute_map = {
        'energy_star_task_id': {'key': 'energyStarTaskId', 'type': 'int'},
        'task_type': {'key': 'taskType', 'type': 'str'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'number_of_places': {'key': 'numberOfPlaces', 'type': 'int'},
        'submission_task_status': {'key': 'submissionTaskStatus', 'type': 'str'},
        'metrics_retrieval_task_status': {'key': 'metricsRetrievalTaskStatus', 'type': 'str'},
        'submission_log_file_name': {'key': 'submissionLogFileName', 'type': 'str'},
        'metrics_retrieval_log_file_name': {'key': 'metricsRetrievalLogFileName', 'type': 'str'},
        'submission_type': {'key': 'submissionType', 'type': 'SubmissionTypeResponse'},
        'places': {'key': 'places', 'type': '[EnergyStarTaskPlaceChild]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarTaskResponse, self).__init__(**kwargs)
        self.energy_star_task_id = kwargs.get('energy_star_task_id', None)
        self.task_type = kwargs.get('task_type', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.user = kwargs.get('user', None)
        self.number_of_places = kwargs.get('number_of_places', None)
        self.submission_task_status = kwargs.get('submission_task_status', None)
        self.metrics_retrieval_task_status = kwargs.get('metrics_retrieval_task_status', None)
        self.submission_log_file_name = kwargs.get('submission_log_file_name', None)
        self.metrics_retrieval_log_file_name = kwargs.get('metrics_retrieval_log_file_name', None)
        self.submission_type = kwargs.get('submission_type', None)
        self.places = kwargs.get('places', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionAccrualExclusion(Model):
    """ListActionAccrualExclusion.

    All required parameters must be populated in order to send to Azure.

    :param exclude: Required. Whether or not the bill ids should be excluded
     from accruals, or included again <span
     class='property-internal'>Required</span>
    :type exclude: bool
    """

    _validation = {
        'exclude': {'required': True},
    }

    _attribute_map = {
        'exclude': {'key': 'exclude', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ListActionAccrualExclusion, self).__init__(**kwargs)
        self.exclude = kwargs.get('exclude', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineProcessorRequest(Model):
    """BaselineProcessorRequest.

    :param include_in_cap: Indicates if the meter will be included in savings
     calculations
    :type include_in_cap: bool
    :param adjust_area: Indicates if floor area adjustments should be made
    :type adjust_area: bool
    :param adjusted_cost_type_id: The type of cost adjustment to perform.
     Possible values include 1 (current average unit cost) and 5 (net cost
     difference)
    :type adjusted_cost_type_id: int
    :param adjust_winter: Indicates if winter weather adjustments should be
     made
    :type adjust_winter: bool
    :param adjust_summer: Indicates if summer weather adjustments should be
     made
    :type adjust_summer: bool
    :param baseline_months: The number of months in the baseline.
     Setting this to anything other than 12 will turn off weather adjustments
     irregardless of the settings in adjustWinter and adjustSummer
    :type baseline_months: int
    :param baseline_start_date: The baseline's start date
    :type baseline_start_date: datetime
    :param savings_start_date: The savings period's start date
    :type savings_start_date: datetime
    :param cooling_temp: The cooling balance point
    :type cooling_temp: int
    :param heating_temp: The heating balance point
    :type heating_temp: int
    :param use_extended_weather: Indicates if extended weather should be used.
     Extended weather uses additional months prior to the baseline start date
     to
     determine weather sensitivity.
    :type use_extended_weather: bool
    :param extended_weather_start_date: The start date of the extended
     weather. This should be 1, 2 or 3 years prior to the baseline start date.
     Extended weather uses additional months prior to the baseline start date
     to
     determine weather sensitivity.
    :type extended_weather_start_date: datetime
    :param baseline_bills: Indicates if each bill in the baseline should be
     included in the baseline regression
    :type baseline_bills:
     list[~energycap.sdk.models.BaselineProcessorRequestBaselineBill]
    """

    _attribute_map = {
        'include_in_cap': {'key': 'includeInCAP', 'type': 'bool'},
        'adjust_area': {'key': 'adjustArea', 'type': 'bool'},
        'adjusted_cost_type_id': {'key': 'adjustedCostTypeId', 'type': 'int'},
        'adjust_winter': {'key': 'adjustWinter', 'type': 'bool'},
        'adjust_summer': {'key': 'adjustSummer', 'type': 'bool'},
        'baseline_months': {'key': 'baselineMonths', 'type': 'int'},
        'baseline_start_date': {'key': 'baselineStartDate', 'type': 'iso-8601'},
        'savings_start_date': {'key': 'savingsStartDate', 'type': 'iso-8601'},
        'cooling_temp': {'key': 'coolingTemp', 'type': 'int'},
        'heating_temp': {'key': 'heatingTemp', 'type': 'int'},
        'use_extended_weather': {'key': 'useExtendedWeather', 'type': 'bool'},
        'extended_weather_start_date': {'key': 'extendedWeatherStartDate', 'type': 'iso-8601'},
        'baseline_bills': {'key': 'baselineBills', 'type': '[BaselineProcessorRequestBaselineBill]'},
    }

    def __init__(self, **kwargs):
        super(BaselineProcessorRequest, self).__init__(**kwargs)
        self.include_in_cap = kwargs.get('include_in_cap', None)
        self.adjust_area = kwargs.get('adjust_area', None)
        self.adjusted_cost_type_id = kwargs.get('adjusted_cost_type_id', None)
        self.adjust_winter = kwargs.get('adjust_winter', None)
        self.adjust_summer = kwargs.get('adjust_summer', None)
        self.baseline_months = kwargs.get('baseline_months', None)
        self.baseline_start_date = kwargs.get('baseline_start_date', None)
        self.savings_start_date = kwargs.get('savings_start_date', None)
        self.cooling_temp = kwargs.get('cooling_temp', None)
        self.heating_temp = kwargs.get('heating_temp', None)
        self.use_extended_weather = kwargs.get('use_extended_weather', None)
        self.extended_weather_start_date = kwargs.get('extended_weather_start_date', None)
        self.baseline_bills = kwargs.get('baseline_bills', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportAdministratorClassPermission(Model):
    """ReportAdministratorClassPermission.

    :param manage:
    :type manage: bool
    """

    _attribute_map = {
        'manage': {'key': 'manage', 'type': 'bool'},
    }

    def __init__(self, *, manage: bool=None, **kwargs) -> None:
        super(ReportAdministratorClassPermission, self).__init__(**kwargs)
        self.manage = manage



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagListAction(Model):
    """FlagListAction.

    :param entity_ids: The entities to update <span
     class='property-internal'>Required (defined)</span>
    :type entity_ids: list[int]
    :param flag_action:
    :type flag_action: ~energycap.sdk.models.FlagEdit
    """

    _attribute_map = {
        'entity_ids': {'key': 'entityIds', 'type': '[int]'},
        'flag_action': {'key': 'flagAction', 'type': 'FlagEdit'},
    }

    def __init__(self, *, entity_ids=None, flag_action=None, **kwargs) -> None:
        super(FlagListAction, self).__init__(**kwargs)
        self.entity_ids = entity_ids
        self.flag_action = flag_action



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowStepChild(Model):
    """ChargebackWorkflowStepChild.

    :param chargeback_workflow_step_id: Identifier for the chargeback workflow
     step
    :type chargeback_workflow_step_id: int
    :param chargeback_workflow_step_info: Name given to the chargeback
     workflow step
    :type chargeback_workflow_step_info: str
    :param chargeback_workflow_step_description: Description for the
     chargeback workflow step
    :type chargeback_workflow_step_description: str
    :param chargeback_workflow_step_type: The chargeback type that can be
     assign to this chargeback workflow step. <span
     class='property-internal'>One of Split, Calculation </span> <span
     class='property-internal'>One of Split, Calculation </span>
    :type chargeback_workflow_step_type: str
    :param chargeback_workflow_step_order: The order for this step within the
     chargeback workflow
    :type chargeback_workflow_step_order: int
    :param chargeback_workflow:
    :type chargeback_workflow: ~energycap.sdk.models.ChargebackWorkflowBase
    """

    _attribute_map = {
        'chargeback_workflow_step_id': {'key': 'chargebackWorkflowStepId', 'type': 'int'},
        'chargeback_workflow_step_info': {'key': 'chargebackWorkflowStepInfo', 'type': 'str'},
        'chargeback_workflow_step_description': {'key': 'chargebackWorkflowStepDescription', 'type': 'str'},
        'chargeback_workflow_step_type': {'key': 'chargebackWorkflowStepType', 'type': 'str'},
        'chargeback_workflow_step_order': {'key': 'chargebackWorkflowStepOrder', 'type': 'int'},
        'chargeback_workflow': {'key': 'chargebackWorkflow', 'type': 'ChargebackWorkflowBase'},
    }

    def __init__(self, **kwargs):
        super(ChargebackWorkflowStepChild, self).__init__(**kwargs)
        self.chargeback_workflow_step_id = kwargs.get('chargeback_workflow_step_id', None)
        self.chargeback_workflow_step_info = kwargs.get('chargeback_workflow_step_info', None)
        self.chargeback_workflow_step_description = kwargs.get('chargeback_workflow_step_description', None)
        self.chargeback_workflow_step_type = kwargs.get('chargeback_workflow_step_type', None)
        self.chargeback_workflow_step_order = kwargs.get('chargeback_workflow_step_order', None)
        self.chargeback_workflow = kwargs.get('chargeback_workflow', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsResponse(Model):
    """EnergyStarSettingsResponse.

    :param pm_account_manager_full_name: Full name of Portfolio Account
     Manager
    :type pm_account_manager_full_name: str
    :param pm_account_manager_user_name: User name of Portfolio Account
     Manager
    :type pm_account_manager_user_name: str
    :param earliest_submission_period: The earliest period to submit
    :type earliest_submission_period: int
    :param unlinked_property_count: Number of Portfolio Manager properties
     that are not linked to any buildings in EnergyCAP
    :type unlinked_property_count: int
    :param linked_property_count: Number of Portfolio Manager properties that
     are linked to a building in EnergyCAP
    :type linked_property_count: int
    :param is_energy_star_available: True if this client is configured for
     ENERGY STAR and Portfolio manager is available. False indicates an issue.
     EnergyStarConfigurationErrorMessage will contain details
    :type is_energy_star_available: bool
    :param energy_star_configuration_error_message: If IsEnergystarAvailable
     is false, this reports the error
    :type energy_star_configuration_error_message: str
    :param is_energy_star_disabled: True if running offline mode or if ENERGY
     STAR has been disabled for this client, false otherwise
    :type is_energy_star_disabled: bool
    :param is_energy_star_configured: True if ENERGY STAR has been configured
    :type is_energy_star_configured: bool
    """

    _attribute_map = {
        'pm_account_manager_full_name': {'key': 'pmAccountManagerFullName', 'type': 'str'},
        'pm_account_manager_user_name': {'key': 'pmAccountManagerUserName', 'type': 'str'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
        'unlinked_property_count': {'key': 'unlinkedPropertyCount', 'type': 'int'},
        'linked_property_count': {'key': 'linkedPropertyCount', 'type': 'int'},
        'is_energy_star_available': {'key': 'isEnergyStarAvailable', 'type': 'bool'},
        'energy_star_configuration_error_message': {'key': 'energyStarConfigurationErrorMessage', 'type': 'str'},
        'is_energy_star_disabled': {'key': 'isEnergyStarDisabled', 'type': 'bool'},
        'is_energy_star_configured': {'key': 'isEnergyStarConfigured', 'type': 'bool'},
    }

    def __init__(self, *, pm_account_manager_full_name: str=None, pm_account_manager_user_name: str=None, earliest_submission_period: int=None, unlinked_property_count: int=None, linked_property_count: int=None, is_energy_star_available: bool=None, energy_star_configuration_error_message: str=None, is_energy_star_disabled: bool=None, is_energy_star_configured: bool=None, **kwargs) -> None:
        super(EnergyStarSettingsResponse, self).__init__(**kwargs)
        self.pm_account_manager_full_name = pm_account_manager_full_name
        self.pm_account_manager_user_name = pm_account_manager_user_name
        self.earliest_submission_period = earliest_submission_period
        self.unlinked_property_count = unlinked_property_count
        self.linked_property_count = linked_property_count
        self.is_energy_star_available = is_energy_star_available
        self.energy_star_configuration_error_message = energy_star_configuration_error_message
        self.is_energy_star_disabled = is_energy_star_disabled
        self.is_energy_star_configured = is_energy_star_configured



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSubmissionRequest(Model):
    """NOTE: this class also serves as a representation of
    EnergyStarTask.settings.

    All required parameters must be populated in order to send to Azure.

    :param places: Required. List of places/submission periods to include in
     ENERGY STAR submission <span class='property-internal'>Required</span>
     <span class='property-internal'>Cannot be Empty</span>
    :type places: list[~energycap.sdk.models.EnergyStarSubmissionPlaceChild]
    """

    _validation = {
        'places': {'required': True},
    }

    _attribute_map = {
        'places': {'key': 'places', 'type': '[EnergyStarSubmissionPlaceChild]'},
    }

    def __init__(self, *, places, **kwargs) -> None:
        super(EnergyStarSubmissionRequest, self).__init__(**kwargs)
        self.places = places



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupPlaceGroupMember(Model):
    """GroupPlaceGroupMember.

    :param place_id: The place identifier <span
     class='property-internal'>Required (defined)</span>
    :type place_id: int
    :param place_code: The place code <span class='property-internal'>Required
     (defined)</span>
    :type place_code: str
    :param place_info: The place info <span class='property-internal'>Required
     (defined)</span>
    :type place_info: str
    :param parent:
    :type parent: ~energycap.sdk.models.PlaceChild
    :param place_type:
    :type place_type: ~energycap.sdk.models.PlaceTypeResponse
    :param include_in_charts: The flag determining whether the place is
     included in group charts <span class='property-internal'>Required
     (defined)</span>
    :type include_in_charts: bool
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'parent': {'key': 'parent', 'type': 'PlaceChild'},
        'place_type': {'key': 'placeType', 'type': 'PlaceTypeResponse'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, *, place_id: int=None, place_code: str=None, place_info: str=None, parent=None, place_type=None, include_in_charts: bool=None, **kwargs) -> None:
        super(GroupPlaceGroupMember, self).__init__(**kwargs)
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.parent = parent
        self.place_type = place_type
        self.include_in_charts = include_in_charts



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListResponseListItem(Model):
    """ListResponseListItem.

    :param field_id:
    :type field_id: int
    :param name:
    :type name: str
    :param value:
    :type value: object
    """

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, *, field_id: int=None, name: str=None, value=None, **kwargs) -> None:
        super(ListResponseListItem, self).__init__(**kwargs)
        self.field_id = field_id
        self.name = name
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Unit(Model):
    """Unit.

    :param unit_id:
    :type unit_id: int
    :param unit_code:  <span class='property-internal'>Must be between 0 and
     16 characters</span>
    :type unit_code: str
    :param unit_info:  <span class='property-internal'>Must be between 0 and
     32 characters</span>
    :type unit_info: str
    :param unit_type:
    :type unit_type: ~energycap.sdk.models.UnitType
    """

    _validation = {
        'unit_code': {'max_length': 16, 'min_length': 0},
        'unit_info': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'unit_id': {'key': 'unitId', 'type': 'int'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'unit_info': {'key': 'unitInfo', 'type': 'str'},
        'unit_type': {'key': 'unitType', 'type': 'UnitType'},
    }

    def __init__(self, **kwargs):
        super(Unit, self).__init__(**kwargs)
        self.unit_id = kwargs.get('unit_id', None)
        self.unit_code = kwargs.get('unit_code', None)
        self.unit_info = kwargs.get('unit_info', None)
        self.unit_type = kwargs.get('unit_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TemplateChild(Model):
    """TemplateChild.

    :param template_id:
    :type template_id: int
    :param template_code:
    :type template_code: str
    :param template_info:
    :type template_info: str
    """

    _attribute_map = {
        'template_id': {'key': 'templateId', 'type': 'int'},
        'template_code': {'key': 'templateCode', 'type': 'str'},
        'template_info': {'key': 'templateInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TemplateChild, self).__init__(**kwargs)
        self.template_id = kwargs.get('template_id', None)
        self.template_code = kwargs.get('template_code', None)
        self.template_info = kwargs.get('template_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Preference(Model):
    """Preferences specific to the logged-in user.

    :param weather_degree_unit: Weather degree unit configured for the user's
     owner
    :type weather_degree_unit: int
    :param meters_show_inactive:
    :type meters_show_inactive: bool
    :param show_data_source: Indicates whether or not to show the datasource
     name
    :type show_data_source: bool
    :param building_tree_display_setting:  <span class='property-internal'>One
     of name, code, namefirst, codefirst </span>
    :type building_tree_display_setting: str
    :param accounts_show_inactive: Indicates whether or not to show inactive
     accounts in the Accounts tree
    :type accounts_show_inactive: bool
    :param cost_center_tree_display_setting: Name/Code display settings for
     the Accounts tree <span class='property-internal'>One of name, code,
     namefirst, codefirst </span>
    :type cost_center_tree_display_setting: str
    :param building_tree_group_to_display:
    :type building_tree_group_to_display: int
    :param vendor_tree_display_setting:  <span class='property-internal'>One
     of name, code, namefirst, codefirst </span>
    :type vendor_tree_display_setting: str
    :param view_vendors_tree_by_commodity:
    :type view_vendors_tree_by_commodity: bool
    :param group_display_setting:
    :type group_display_setting: ~energycap.sdk.models.GroupDisplaySetting
    :param bill_list_rows_per_page: Number of rows to display in bill lists
    :type bill_list_rows_per_page: int
    :param date_format: Date format for the user
    :type date_format: str
    :param time_format: Time format for the user
    :type time_format: str
    :param time_zone_code: Code of the default time zone configured for the
     user's owner
    :type time_zone_code: str
    :param trend_chart_number_of_years: Number of years to display in trend
     charts when the user views them
    :type trend_chart_number_of_years: int
    :param language: User's language preference
    :type language: str
    :param building_and_organization_identifier: Value to use when displaying
     a single building or organization (name or code)
    :type building_and_organization_identifier: str
    :param meter_identifier: Value to use when displaying a single meter (name
     or code)
    :type meter_identifier: str
    :param account_identifier: Value to use when displaying a single account
     (name or code)
    :type account_identifier: str
    :param other_identifier: Value to use when displaying generic items (name
     or code)
    :type other_identifier: str
    :param help_open: Indicates whether or not in-app help is open
    :type help_open: bool
    :param workflow_display_setting:
    :type workflow_display_setting:
     ~energycap.sdk.models.WorkflowDisplaySetting
    """

    _attribute_map = {
        'weather_degree_unit': {'key': 'weatherDegreeUnit', 'type': 'int'},
        'meters_show_inactive': {'key': 'metersShowInactive', 'type': 'bool'},
        'show_data_source': {'key': 'showDataSource', 'type': 'bool'},
        'building_tree_display_setting': {'key': 'buildingTreeDisplaySetting', 'type': 'str'},
        'accounts_show_inactive': {'key': 'accountsShowInactive', 'type': 'bool'},
        'cost_center_tree_display_setting': {'key': 'costCenterTreeDisplaySetting', 'type': 'str'},
        'building_tree_group_to_display': {'key': 'buildingTreeGroupToDisplay', 'type': 'int'},
        'vendor_tree_display_setting': {'key': 'vendorTreeDisplaySetting', 'type': 'str'},
        'view_vendors_tree_by_commodity': {'key': 'viewVendorsTreeByCommodity', 'type': 'bool'},
        'group_display_setting': {'key': 'groupDisplaySetting', 'type': 'GroupDisplaySetting'},
        'bill_list_rows_per_page': {'key': 'billListRowsPerPage', 'type': 'int'},
        'date_format': {'key': 'dateFormat', 'type': 'str'},
        'time_format': {'key': 'timeFormat', 'type': 'str'},
        'time_zone_code': {'key': 'timeZoneCode', 'type': 'str'},
        'trend_chart_number_of_years': {'key': 'trendChartNumberOfYears', 'type': 'int'},
        'language': {'key': 'language', 'type': 'str'},
        'building_and_organization_identifier': {'key': 'buildingAndOrganizationIdentifier', 'type': 'str'},
        'meter_identifier': {'key': 'meterIdentifier', 'type': 'str'},
        'account_identifier': {'key': 'accountIdentifier', 'type': 'str'},
        'other_identifier': {'key': 'otherIdentifier', 'type': 'str'},
        'help_open': {'key': 'helpOpen', 'type': 'bool'},
        'workflow_display_setting': {'key': 'workflowDisplaySetting', 'type': 'WorkflowDisplaySetting'},
    }

    def __init__(self, *, weather_degree_unit: int=None, meters_show_inactive: bool=None, show_data_source: bool=None, building_tree_display_setting: str=None, accounts_show_inactive: bool=None, cost_center_tree_display_setting: str=None, building_tree_group_to_display: int=None, vendor_tree_display_setting: str=None, view_vendors_tree_by_commodity: bool=None, group_display_setting=None, bill_list_rows_per_page: int=None, date_format: str=None, time_format: str=None, time_zone_code: str=None, trend_chart_number_of_years: int=None, language: str=None, building_and_organization_identifier: str=None, meter_identifier: str=None, account_identifier: str=None, other_identifier: str=None, help_open: bool=None, workflow_display_setting=None, **kwargs) -> None:
        super(Preference, self).__init__(**kwargs)
        self.weather_degree_unit = weather_degree_unit
        self.meters_show_inactive = meters_show_inactive
        self.show_data_source = show_data_source
        self.building_tree_display_setting = building_tree_display_setting
        self.accounts_show_inactive = accounts_show_inactive
        self.cost_center_tree_display_setting = cost_center_tree_display_setting
        self.building_tree_group_to_display = building_tree_group_to_display
        self.vendor_tree_display_setting = vendor_tree_display_setting
        self.view_vendors_tree_by_commodity = view_vendors_tree_by_commodity
        self.group_display_setting = group_display_setting
        self.bill_list_rows_per_page = bill_list_rows_per_page
        self.date_format = date_format
        self.time_format = time_format
        self.time_zone_code = time_zone_code
        self.trend_chart_number_of_years = trend_chart_number_of_years
        self.language = language
        self.building_and_organization_identifier = building_and_organization_identifier
        self.meter_identifier = meter_identifier
        self.account_identifier = account_identifier
        self.other_identifier = other_identifier
        self.help_open = help_open
        self.workflow_display_setting = workflow_display_setting



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillDeleteActionResult(Model):
    """BillDeleteActionResult.

    :param selected:
    :type selected: int
    :param deleted:
    :type deleted: int
    """

    _attribute_map = {
        'selected': {'key': 'selected', 'type': 'int'},
        'deleted': {'key': 'deleted', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(BillDeleteActionResult, self).__init__(**kwargs)
        self.selected = kwargs.get('selected', None)
        self.deleted = kwargs.get('deleted', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookCreateRequest(Model):
    """WebhookCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param webhook_name: Required. The name of the webhook <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type webhook_name: str
    :param webhook_description: The description for the webhook
    :type webhook_description: str
    :param webhook_event_type_id: Required. The type of event that will
     trigger the webhook <span class='property-internal'>Required</span>
    :type webhook_event_type_id: int
    :param mailing_list: Required. List of email addresses. Each recipient in
     this list will receive an email when a webhook fails or gets disabled
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type mailing_list: list[str]
    :param url: Required. The URL to be invoked by the webhook <span
     class='property-internal'>Required</span>
    :type url: str
    :param secret: Required. The encryption secret. <span
     class='property-internal'>Required</span>
    :type secret: str
    """

    _validation = {
        'webhook_name': {'required': True, 'max_length': 64, 'min_length': 0},
        'webhook_event_type_id': {'required': True},
        'mailing_list': {'required': True},
        'url': {'required': True},
        'secret': {'required': True},
    }

    _attribute_map = {
        'webhook_name': {'key': 'webhookName', 'type': 'str'},
        'webhook_description': {'key': 'webhookDescription', 'type': 'str'},
        'webhook_event_type_id': {'key': 'webhookEventTypeId', 'type': 'int'},
        'mailing_list': {'key': 'mailingList', 'type': '[str]'},
        'url': {'key': 'url', 'type': 'str'},
        'secret': {'key': 'secret', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(WebhookCreateRequest, self).__init__(**kwargs)
        self.webhook_name = kwargs.get('webhook_name', None)
        self.webhook_description = kwargs.get('webhook_description', None)
        self.webhook_event_type_id = kwargs.get('webhook_event_type_id', None)
        self.mailing_list = kwargs.get('mailing_list', None)
        self.url = kwargs.get('url', None)
        self.secret = kwargs.get('secret', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportChild(Model):
    """ReportChild.

    :param version: The version of the report
    :type version: str
    :param report_id: The identifier of the report
    :type report_id: int
    :param report_code: The report code
    :type report_code: str
    :param report_info: The report name
    :type report_info: str
    :param report_type:
    :type report_type: ~energycap.sdk.models.ReportType
    :param description: The report description
    :type description: str
    :param is_landscape: Indicates whether or not the report is rendered in
     landscape
    :type is_landscape: bool
    :param last_updated: The last time this report was updated
    :type last_updated: datetime
    :param tags: Tags describing features of the report
    :type tags: list[~energycap.sdk.models.TagChild]
    :param export_formats: Supported export formats (EnergyCAP currently
     supports PDF, Word, Excel, Excel data only, Excel formatted, and CSV)
    :type export_formats: list[~energycap.sdk.models.ExportFormatChild]
    :param report_source: The rendering engine used for the report (EnergyCAP
     currently uses SSRS and Crystal)
    :type report_source: str
    """

    _attribute_map = {
        'version': {'key': 'version', 'type': 'str'},
        'report_id': {'key': 'reportId', 'type': 'int'},
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'report_info': {'key': 'reportInfo', 'type': 'str'},
        'report_type': {'key': 'reportType', 'type': 'ReportType'},
        'description': {'key': 'description', 'type': 'str'},
        'is_landscape': {'key': 'isLandscape', 'type': 'bool'},
        'last_updated': {'key': 'lastUpdated', 'type': 'iso-8601'},
        'tags': {'key': 'tags', 'type': '[TagChild]'},
        'export_formats': {'key': 'exportFormats', 'type': '[ExportFormatChild]'},
        'report_source': {'key': 'reportSource', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ReportChild, self).__init__(**kwargs)
        self.version = kwargs.get('version', None)
        self.report_id = kwargs.get('report_id', None)
        self.report_code = kwargs.get('report_code', None)
        self.report_info = kwargs.get('report_info', None)
        self.report_type = kwargs.get('report_type', None)
        self.description = kwargs.get('description', None)
        self.is_landscape = kwargs.get('is_landscape', None)
        self.last_updated = kwargs.get('last_updated', None)
        self.tags = kwargs.get('tags', None)
        self.export_formats = kwargs.get('export_formats', None)
        self.report_source = kwargs.get('report_source', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseMetaData(Model):
    """DataAccessReleaseMetaData.

    :param account_number:
    :type account_number: str
    :param name_on_bill:
    :type name_on_bill: str
    :param service_address:
    :type service_address: str
    """

    _attribute_map = {
        'account_number': {'key': 'accountNumber', 'type': 'str'},
        'name_on_bill': {'key': 'nameOnBill', 'type': 'str'},
        'service_address': {'key': 'serviceAddress', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataAccessReleaseMetaData, self).__init__(**kwargs)
        self.account_number = kwargs.get('account_number', None)
        self.name_on_bill = kwargs.get('name_on_bill', None)
        self.service_address = kwargs.get('service_address', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterChildSearch(Model):
    """Class derived from MeterChildDTO - has Meter Address and Serial Number
    This class is used by the Bill Entry Account Searcher.

    :param meter_address:
    :type meter_address: ~energycap.sdk.models.AddressChild
    :param serial_number: The meter's current serial number
    :type serial_number: str
    :param previous_serial_number: The meter's previous serial number
    :type previous_serial_number: str
    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param meter_type:
    :type meter_type: ~energycap.sdk.models.MeterTypeChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param active: Indicates whether the Meter is Active
    :type active: bool
    :param is_calculated_meter: Indicates whether the Meter is a calculated
     meter
    :type is_calculated_meter: bool
    :param is_split_parent_meter: Indicates whether the Meter is a parent of a
     split
    :type is_split_parent_meter: bool
    :param is_split_child_meter: Indicates whether the Meter is a child of a
     split
    :type is_split_child_meter: bool
    """

    _attribute_map = {
        'meter_address': {'key': 'meterAddress', 'type': 'AddressChild'},
        'serial_number': {'key': 'serialNumber', 'type': 'str'},
        'previous_serial_number': {'key': 'previousSerialNumber', 'type': 'str'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_type': {'key': 'meterType', 'type': 'MeterTypeChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'active': {'key': 'active', 'type': 'bool'},
        'is_calculated_meter': {'key': 'isCalculatedMeter', 'type': 'bool'},
        'is_split_parent_meter': {'key': 'isSplitParentMeter', 'type': 'bool'},
        'is_split_child_meter': {'key': 'isSplitChildMeter', 'type': 'bool'},
    }

    def __init__(self, *, meter_address=None, serial_number: str=None, previous_serial_number: str=None, meter_id: int=None, meter_code: str=None, meter_info: str=None, meter_type=None, commodity=None, active: bool=None, is_calculated_meter: bool=None, is_split_parent_meter: bool=None, is_split_child_meter: bool=None, **kwargs) -> None:
        super(MeterChildSearch, self).__init__(**kwargs)
        self.meter_address = meter_address
        self.serial_number = serial_number
        self.previous_serial_number = previous_serial_number
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.meter_type = meter_type
        self.commodity = commodity
        self.active = active
        self.is_calculated_meter = is_calculated_meter
        self.is_split_parent_meter = is_split_parent_meter
        self.is_split_child_meter = is_split_child_meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TemplateResponse(Model):
    """TemplateResponse.

    :param template_id:
    :type template_id: int
    :param template_code:
    :type template_code: str
    :param template_info:
    :type template_info: str
    :param note:
    :type note: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param demand_unit:
    :type demand_unit: ~energycap.sdk.models.UnitChild
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param versions:
    :type versions: list[~energycap.sdk.models.VersionChild]
    """

    _attribute_map = {
        'template_id': {'key': 'templateId', 'type': 'int'},
        'template_code': {'key': 'templateCode', 'type': 'str'},
        'template_info': {'key': 'templateInfo', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'demand_unit': {'key': 'demandUnit', 'type': 'UnitChild'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'versions': {'key': 'versions', 'type': '[VersionChild]'},
    }

    def __init__(self, *, template_id: int=None, template_code: str=None, template_info: str=None, note: str=None, commodity=None, demand_unit=None, use_unit=None, versions=None, **kwargs) -> None:
        super(TemplateResponse, self).__init__(**kwargs)
        self.template_id = template_id
        self.template_code = template_code
        self.template_info = template_info
        self.note = note
        self.commodity = commodity
        self.demand_unit = demand_unit
        self.use_unit = use_unit
        self.versions = versions



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DeleteReadingResponse(Model):
    """DeleteReadingResponse.

    :param deleted: The number of readings deleted
    :type deleted: int
    :param failures: Data representing the failed reading deletion
    :type failures: list[~energycap.sdk.models.ReadingDelete]
    """

    _attribute_map = {
        'deleted': {'key': 'deleted', 'type': 'int'},
        'failures': {'key': 'failures', 'type': '[ReadingDelete]'},
    }

    def __init__(self, **kwargs):
        super(DeleteReadingResponse, self).__init__(**kwargs)
        self.deleted = kwargs.get('deleted', None)
        self.failures = kwargs.get('failures', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryBodyLine(Model):
    """BillEntryBodyLine.

    :param body_line_id: The body line identifier
    :type body_line_id: int
    :param caption: The body line's caption
    :type caption: str
    :param value:
    :type value: ~energycap.sdk.models.BillEntryBodyLineWithNounChild
    :param cost:
    :type cost: ~energycap.sdk.models.BillEntryBodyLineChild
    :param observation_type:
    :type observation_type:
     ~energycap.sdk.models.BillEntryObservationTypeChild
    """

    _attribute_map = {
        'body_line_id': {'key': 'bodyLineId', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
        'value': {'key': 'value', 'type': 'BillEntryBodyLineWithNounChild'},
        'cost': {'key': 'cost', 'type': 'BillEntryBodyLineChild'},
        'observation_type': {'key': 'observationType', 'type': 'BillEntryObservationTypeChild'},
    }

    def __init__(self, **kwargs):
        super(BillEntryBodyLine, self).__init__(**kwargs)
        self.body_line_id = kwargs.get('body_line_id', None)
        self.caption = kwargs.get('caption', None)
        self.value = kwargs.get('value', None)
        self.cost = kwargs.get('cost', None)
        self.observation_type = kwargs.get('observation_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelCreate(Model):
    """ChannelCreate.

    All required parameters must be populated in order to send to Azure.

    :param interval_minutes: Required. The interval of the channel in minutes
     15 = FifteenMinute,
     30 = ThirtyMinute,
     60 = Hourly,
     1440 = Daily,
     10080 = Weekly,
     43200 = Monthly <span class='property-internal'>Required</span> <span
     class='property-internal'>One of 15, 30, 60, 1440, 10080, 43200 </span>
    :type interval_minutes: int
    :param observation_type_code: Required. The observation type of the
     channel <span class='property-internal'>Required</span>
    :type observation_type_code: str
    :param channel_description: Description of the channel <span
     class='property-internal'>Must be between 0 and 4000 characters</span>
    :type channel_description: str
    :param channel_import_id: The import identifier for the channel <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type channel_import_id: str
    :param channel_version: Required.
    :type channel_version: ~energycap.sdk.models.ChannelVersionRequest
    """

    _validation = {
        'interval_minutes': {'required': True},
        'observation_type_code': {'required': True},
        'channel_description': {'max_length': 4000, 'min_length': 0},
        'channel_import_id': {'max_length': 255, 'min_length': 0},
        'channel_version': {'required': True},
    }

    _attribute_map = {
        'interval_minutes': {'key': 'intervalMinutes', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'channel_description': {'key': 'channelDescription', 'type': 'str'},
        'channel_import_id': {'key': 'channelImportId', 'type': 'str'},
        'channel_version': {'key': 'channelVersion', 'type': 'ChannelVersionRequest'},
    }

    def __init__(self, **kwargs):
        super(ChannelCreate, self).__init__(**kwargs)
        self.interval_minutes = kwargs.get('interval_minutes', None)
        self.observation_type_code = kwargs.get('observation_type_code', None)
        self.channel_description = kwargs.get('channel_description', None)
        self.channel_import_id = kwargs.get('channel_import_id', None)
        self.channel_version = kwargs.get('channel_version', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportCreate(Model):
    """ReportCreate.

    All required parameters must be populated in order to send to Azure.

    :param report_code: Required. New specific report code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type report_code: str
    :param report_info: Required. New specific report name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type report_info: str
    :param report_description: Required. New specific report description <span
     class='property-internal'>Required</span>
    :type report_description: str
    """

    _validation = {
        'report_code': {'required': True, 'max_length': 255, 'min_length': 0},
        'report_info': {'required': True, 'max_length': 255, 'min_length': 0},
        'report_description': {'required': True},
    }

    _attribute_map = {
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'report_info': {'key': 'reportInfo', 'type': 'str'},
        'report_description': {'key': 'reportDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ReportCreate, self).__init__(**kwargs)
        self.report_code = kwargs.get('report_code', None)
        self.report_info = kwargs.get('report_info', None)
        self.report_description = kwargs.get('report_description', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleResponse(Model):
    """SystemUserRoleResponse.

    :param system_user_role_id:
    :type system_user_role_id: int
    :param system_user_role_name:
    :type system_user_role_name: str
    :param description:
    :type description: str
    :param users_assigned_count:
    :type users_assigned_count: int
    :param permissions:
    :type permissions: ~energycap.sdk.models.Permissions
    :param read_only:
    :type read_only: bool
    """

    _attribute_map = {
        'system_user_role_id': {'key': 'systemUserRoleId', 'type': 'int'},
        'system_user_role_name': {'key': 'systemUserRoleName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'users_assigned_count': {'key': 'usersAssignedCount', 'type': 'int'},
        'permissions': {'key': 'permissions', 'type': 'Permissions'},
        'read_only': {'key': 'readOnly', 'type': 'bool'},
    }

    def __init__(self, *, system_user_role_id: int=None, system_user_role_name: str=None, description: str=None, users_assigned_count: int=None, permissions=None, read_only: bool=None, **kwargs) -> None:
        super(SystemUserRoleResponse, self).__init__(**kwargs)
        self.system_user_role_id = system_user_role_id
        self.system_user_role_name = system_user_role_name
        self.description = description
        self.users_assigned_count = users_assigned_count
        self.permissions = permissions
        self.read_only = read_only



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserEditRequest(Model):
    """UserEditRequest.

    All required parameters must be populated in order to send to Azure.

    :param user_code: Required. The user code. This is the user name that is
     used on sign-in <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 65 characters</span>
    :type user_code: str
    :param full_name: Required. The user's full name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type full_name: str
    :param password: The user's password. Password is not changed if this
     field is empty.
     Not available for users whose identity is managed externally. <span
     class='property-internal'>Must be between 0 and 128 characters</span>
     <span class='property-internal'>Required (defined)</span>
    :type password: str
    :param email: Required. The user's email address <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type email: str
    :param cost_center_id: NOTE: This property will be deprecated
     Use TopmostCostCenterIds with a single valued list to update a user to a
     single topmost cost center
     Update a user to a single topmost cost center id
     The CostCenterId must be in the editing user's topmost
     If this value is not null then TopmostCostCenterIds must be null <span
     class='property-internal'>Topmost (CostCenter)</span> <span
     class='property-internal'>Required (defined)</span>
    :type cost_center_id: int
    :param topmost_cost_center_ids: Update a user to one multiple topmost cost
     center ids
     The CostCenterIds must be in the editing user's topmost
     If this is not null then CostCenterId must be null <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>NULL Valid</span> <span
     class='property-internal'>Required (defined)</span>
    :type topmost_cost_center_ids: list[int]
    :param place_id: NOTE: This property will be deprecated
     Use TopmostPlaceIds with a single valued list to update a user to a single
     topmost place
     Update a user to a single topmost place id
     The PlaceId must be in the editing user's topmost
     If this value is not null then TopmostPlaceIds must be null <span
     class='property-internal'>Topmost (Place)</span> <span
     class='property-internal'>Required (defined)</span>
    :type place_id: int
    :param topmost_place_ids: Update a user to one or multiple topmost place
     ids
     The PlaceIds must be in the editing user's topmost
     If this is not null then PlaceId must be null <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>NULL Valid</span> <span
     class='property-internal'>Required (defined)</span>
    :type topmost_place_ids: list[int]
    :param active_directory: Required. Whether or not the user signs in using
     active directory. This is used for install client only <span
     class='property-internal'>Required</span>
    :type active_directory: bool
    :param active: Required. Whether or not the user is active <span
     class='property-internal'>Required</span>
    :type active: bool
    :param password_expiration_interval: Required. Days until the user's
     password expires
     Must be set to 0 for users whose identity is managed externally. <span
     class='property-internal'>Required</span>
    :type password_expiration_interval: int
    :param strong_password: Required. Force the user's password to have a
     minimum of 8 characters,
     containing at least 1 uppercase, 1 lowercase, 1 number, and 1 symbol.
     Must be set to false for users whose identity is managed externally. <span
     class='property-internal'>Required</span>
    :type strong_password: bool
    :param force_password_change: Required. Force the user to change their
     password on next login.
     Must be set to false for users whose identity is managed externally. <span
     class='property-internal'>Required</span>
    :type force_password_change: bool
    :param user_role_id: Required. The user's role <span
     class='property-internal'>Required</span>
    :type user_role_id: int
    :param max_approval_amount: The maximum bill amount (in dollars) the user
     can approve
     If not included, the user has no max limit <span
     class='property-internal'>Required (defined)</span>
    :type max_approval_amount: int
    :param report_group_id: Required. The user's report group. If not
     included, set to the default report group <span
     class='property-internal'>Required</span>
    :type report_group_id: int
    :param user_groups: List of user group ids
     If null or not passed the groups a user assigned to will NOT be modified
     If an empty list the user will be removed from all groups <span
     class='property-internal'>Required (defined)</span>
    :type user_groups: list[int]
    """

    _validation = {
        'user_code': {'required': True, 'max_length': 65, 'min_length': 0},
        'full_name': {'required': True, 'max_length': 32, 'min_length': 0},
        'password': {'max_length': 128, 'min_length': 0},
        'email': {'required': True, 'max_length': 128, 'min_length': 0},
        'active_directory': {'required': True},
        'active': {'required': True},
        'password_expiration_interval': {'required': True},
        'strong_password': {'required': True},
        'force_password_change': {'required': True},
        'user_role_id': {'required': True},
        'report_group_id': {'required': True},
    }

    _attribute_map = {
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'password': {'key': 'password', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'topmost_cost_center_ids': {'key': 'topmostCostCenterIds', 'type': '[int]'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'topmost_place_ids': {'key': 'topmostPlaceIds', 'type': '[int]'},
        'active_directory': {'key': 'activeDirectory', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'password_expiration_interval': {'key': 'passwordExpirationInterval', 'type': 'int'},
        'strong_password': {'key': 'strongPassword', 'type': 'bool'},
        'force_password_change': {'key': 'forcePasswordChange', 'type': 'bool'},
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
        'max_approval_amount': {'key': 'maxApprovalAmount', 'type': 'int'},
        'report_group_id': {'key': 'reportGroupId', 'type': 'int'},
        'user_groups': {'key': 'userGroups', 'type': '[int]'},
    }

    def __init__(self, *, user_code: str, full_name: str, email: str, active_directory: bool, active: bool, password_expiration_interval: int, strong_password: bool, force_password_change: bool, user_role_id: int, report_group_id: int, password: str=None, cost_center_id: int=None, topmost_cost_center_ids=None, place_id: int=None, topmost_place_ids=None, max_approval_amount: int=None, user_groups=None, **kwargs) -> None:
        super(UserEditRequest, self).__init__(**kwargs)
        self.user_code = user_code
        self.full_name = full_name
        self.password = password
        self.email = email
        self.cost_center_id = cost_center_id
        self.topmost_cost_center_ids = topmost_cost_center_ids
        self.place_id = place_id
        self.topmost_place_ids = topmost_place_ids
        self.active_directory = active_directory
        self.active = active
        self.password_expiration_interval = password_expiration_interval
        self.strong_password = strong_password
        self.force_password_change = force_password_change
        self.user_role_id = user_role_id
        self.max_approval_amount = max_approval_amount
        self.report_group_id = report_group_id
        self.user_groups = user_groups



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LoginResponse(Model):
    """LoginResponse.

    :param token:
    :type token: str
    :param user:
    :type user: ~energycap.sdk.models.ApiUser
    """

    _attribute_map = {
        'token': {'key': 'token', 'type': 'str'},
        'user': {'key': 'user', 'type': 'ApiUser'},
    }

    def __init__(self, *, token: str=None, user=None, **kwargs) -> None:
        super(LoginResponse, self).__init__(**kwargs)
        self.token = token
        self.user = user



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApprovalWorkflowChild(Model):
    """ApprovalWorkflowChild.

    :param approval_mode_enabled:
    :type approval_mode_enabled: bool
    :param confirm_edit_delete:
    :type confirm_edit_delete: bool
    """

    _attribute_map = {
        'approval_mode_enabled': {'key': 'approvalModeEnabled', 'type': 'bool'},
        'confirm_edit_delete': {'key': 'confirmEditDelete', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ApprovalWorkflowChild, self).__init__(**kwargs)
        self.approval_mode_enabled = kwargs.get('approval_mode_enabled', None)
        self.confirm_edit_delete = kwargs.get('confirm_edit_delete', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGMonthlyResponseGHGCommodity(Model):
    """PlaceDigestGHGMonthlyResponseGHGCommodity.

    :param commodity_id: Commodity Id
    :type commodity_id: int
    :param commodity_code: Commodity Code
    :type commodity_code: str
    :param commodity_info: Commodity info
    :type commodity_info: str
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestGHGMonthlyResponseTargetComparison
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGMonthlyResponseResults]
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestGHGMonthlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGMonthlyResponseResults]'},
    }

    def __init__(self, *, commodity_id: int=None, commodity_code: str=None, commodity_info: str=None, target_comparison=None, results=None, **kwargs) -> None:
        super(PlaceDigestGHGMonthlyResponseGHGCommodity, self).__init__(**kwargs)
        self.commodity_id = commodity_id
        self.commodity_code = commodity_code
        self.commodity_info = commodity_info
        self.target_comparison = target_comparison
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodUseCostChild(Model):
    """BillingPeriodUseCostChild.

    :param billing_period: The billing period that the data represents.
     Will be the current billing period, the same year prior billing period,
     or the same period prior year billing period.
    :type billing_period: int
    :param number_of_bills_in_period: The number of bills in the current
     billing period.
    :type number_of_bills_in_period: int
    :param number_of_bills_in_period_from_workflow_step: The number of bills
     in the current billing period that were generated by this workflow step.
    :type number_of_bills_in_period_from_workflow_step: int
    :param use:
    :type use: ~energycap.sdk.models.BillingPeriodUseUnitChild
    :param cost:
    :type cost: ~energycap.sdk.models.BillingPeriodCostUnitChild
    :param unit_cost: The unit cost for the specified billing period.
    :type unit_cost: float
    """

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'number_of_bills_in_period': {'key': 'numberOfBillsInPeriod', 'type': 'int'},
        'number_of_bills_in_period_from_workflow_step': {'key': 'numberOfBillsInPeriodFromWorkflowStep', 'type': 'int'},
        'use': {'key': 'use', 'type': 'BillingPeriodUseUnitChild'},
        'cost': {'key': 'cost', 'type': 'BillingPeriodCostUnitChild'},
        'unit_cost': {'key': 'unitCost', 'type': 'float'},
    }

    def __init__(self, *, billing_period: int=None, number_of_bills_in_period: int=None, number_of_bills_in_period_from_workflow_step: int=None, use=None, cost=None, unit_cost: float=None, **kwargs) -> None:
        super(BillingPeriodUseCostChild, self).__init__(**kwargs)
        self.billing_period = billing_period
        self.number_of_bills_in_period = number_of_bills_in_period
        self.number_of_bills_in_period_from_workflow_step = number_of_bills_in_period_from_workflow_step
        self.use = use
        self.cost = cost
        self.unit_cost = unit_cost



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PrimaryUseChild(Model):
    """PrimaryUseChild.

    :param primary_use_id:
    :type primary_use_id: int
    :param primary_use_code:
    :type primary_use_code: str
    :param primary_use_info:
    :type primary_use_info: str
    """

    _attribute_map = {
        'primary_use_id': {'key': 'primaryUseId', 'type': 'int'},
        'primary_use_code': {'key': 'primaryUseCode', 'type': 'str'},
        'primary_use_info': {'key': 'primaryUseInfo', 'type': 'str'},
    }

    def __init__(self, *, primary_use_id: int=None, primary_use_code: str=None, primary_use_info: str=None, **kwargs) -> None:
        super(PrimaryUseChild, self).__init__(**kwargs)
        self.primary_use_id = primary_use_id
        self.primary_use_code = primary_use_code
        self.primary_use_info = primary_use_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemSettingsResponse(Model):
    """SystemSettingsResponse.

    :param organization_name: The organization name
    :type organization_name: str
    :param display_organization_name_in_header: Indicates whether or not
     organization name should be displayed in the application header
    :type display_organization_name_in_header: bool
    :param organization_logo: The organization logo
     May be a base64-encoded PNG, JPG, or SVG image or a URI for an image
     hosted online
     A null value will clear the saved image
    :type organization_logo: str
    :param automatic_logout_minutes: Number of minutes after which users will
     be automatically logged out
    :type automatic_logout_minutes: int
    :param default_country: Default country for new users
    :type default_country: str
    :param default_meter_time_zone:
    :type default_meter_time_zone: ~energycap.sdk.models.TimeZoneResponse
    :param default_date_format: Default date format for new users
    :type default_date_format: str
    :param default_topmost_place:
    :type default_topmost_place: ~energycap.sdk.models.PlaceChild
    :param default_cost_center:
    :type default_cost_center: ~energycap.sdk.models.CostCenterChild
    :param default_user_role:
    :type default_user_role: ~energycap.sdk.models.SystemUserRoleChild
    """

    _attribute_map = {
        'organization_name': {'key': 'organizationName', 'type': 'str'},
        'display_organization_name_in_header': {'key': 'displayOrganizationNameInHeader', 'type': 'bool'},
        'organization_logo': {'key': 'organizationLogo', 'type': 'str'},
        'automatic_logout_minutes': {'key': 'automaticLogoutMinutes', 'type': 'int'},
        'default_country': {'key': 'defaultCountry', 'type': 'str'},
        'default_meter_time_zone': {'key': 'defaultMeterTimeZone', 'type': 'TimeZoneResponse'},
        'default_date_format': {'key': 'defaultDateFormat', 'type': 'str'},
        'default_topmost_place': {'key': 'defaultTopmostPlace', 'type': 'PlaceChild'},
        'default_cost_center': {'key': 'defaultCostCenter', 'type': 'CostCenterChild'},
        'default_user_role': {'key': 'defaultUserRole', 'type': 'SystemUserRoleChild'},
    }

    def __init__(self, *, organization_name: str=None, display_organization_name_in_header: bool=None, organization_logo: str=None, automatic_logout_minutes: int=None, default_country: str=None, default_meter_time_zone=None, default_date_format: str=None, default_topmost_place=None, default_cost_center=None, default_user_role=None, **kwargs) -> None:
        super(SystemSettingsResponse, self).__init__(**kwargs)
        self.organization_name = organization_name
        self.display_organization_name_in_header = display_organization_name_in_header
        self.organization_logo = organization_logo
        self.automatic_logout_minutes = automatic_logout_minutes
        self.default_country = default_country
        self.default_meter_time_zone = default_meter_time_zone
        self.default_date_format = default_date_format
        self.default_topmost_place = default_topmost_place
        self.default_cost_center = default_cost_center
        self.default_user_role = default_user_role



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MissingBillWidget(Model):
    """MissingBillWidget.

    :param gap_begin_date: The begin date of the gap in billing data
    :type gap_begin_date: datetime
    :param gap_end_date: The end date of the gap in billing data
    :type gap_end_date: datetime
    :param gap_days: The number of days in the gap in billing data
    :type gap_days: int
    :param account_id: The account that is missing billing data
    :type account_id: int
    :param account_info: The account that is missing billing data
    :type account_info: str
    :param meter_info: The meter that is missing billing data
    :type meter_info: str
    """

    _attribute_map = {
        'gap_begin_date': {'key': 'gapBeginDate', 'type': 'iso-8601'},
        'gap_end_date': {'key': 'gapEndDate', 'type': 'iso-8601'},
        'gap_days': {'key': 'gapDays', 'type': 'int'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MissingBillWidget, self).__init__(**kwargs)
        self.gap_begin_date = kwargs.get('gap_begin_date', None)
        self.gap_end_date = kwargs.get('gap_end_date', None)
        self.gap_days = kwargs.get('gap_days', None)
        self.account_id = kwargs.get('account_id', None)
        self.account_info = kwargs.get('account_info', None)
        self.meter_info = kwargs.get('meter_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestNormalizedMonthlyResponseResults(Model):
    """MeterDigestNormalizedMonthlyResponseResults.

    :param period_name: Calendar Period Name
    :type period_name: str
    :param calendar_period: Calendar Period
    :type calendar_period: int
    :param calendar_year: Calendar Year
    :type calendar_year: int
    :param fiscal_period: Fiscal Period
    :type fiscal_period: int
    :param fiscal_year: Fiscal Year
    :type fiscal_year: int
    :param days: The number of days in the period
    :type days: int
    :param cumulative_native_use: Cumulative Native Use
    :type cumulative_native_use: float
    :param native_use: Native Use
    :type native_use: float
    :param common_use: Common Use
    :type common_use: float
    :param native_actual_demand: Native Actual Demand
    :type native_actual_demand: float
    :param native_billed_demand: Native Billed Demand
    :type native_billed_demand: float
    :param load_factor: Load Factor
    :type load_factor: float
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'days': {'key': 'days', 'type': 'int'},
        'cumulative_native_use': {'key': 'cumulativeNativeUse', 'type': 'float'},
        'native_use': {'key': 'nativeUse', 'type': 'float'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'native_actual_demand': {'key': 'nativeActualDemand', 'type': 'float'},
        'native_billed_demand': {'key': 'nativeBilledDemand', 'type': 'float'},
        'load_factor': {'key': 'loadFactor', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(MeterDigestNormalizedMonthlyResponseResults, self).__init__(**kwargs)
        self.period_name = kwargs.get('period_name', None)
        self.calendar_period = kwargs.get('calendar_period', None)
        self.calendar_year = kwargs.get('calendar_year', None)
        self.fiscal_period = kwargs.get('fiscal_period', None)
        self.fiscal_year = kwargs.get('fiscal_year', None)
        self.days = kwargs.get('days', None)
        self.cumulative_native_use = kwargs.get('cumulative_native_use', None)
        self.native_use = kwargs.get('native_use', None)
        self.common_use = kwargs.get('common_use', None)
        self.native_actual_demand = kwargs.get('native_actual_demand', None)
        self.native_billed_demand = kwargs.get('native_billed_demand', None)
        self.load_factor = kwargs.get('load_factor', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .energy_cap_api import EnergyCapApi
from .version import VERSION

__all__ = ['EnergyCapApi']

__version__ = VERSION




# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SumResponse(Model):
    """SumResponse.

    :param sum_meters: Meters in this list will have their use or cost added
     together during the bill calculation
    :type sum_meters: list[~energycap.sdk.models.MeterChild]
    :param sum_meter_groups: Distinct meters from these meter groups will have
     their use or cost added together during the bill calculation
    :type sum_meter_groups: list[~energycap.sdk.models.MeterGroupChild]
    """

    _attribute_map = {
        'sum_meters': {'key': 'sumMeters', 'type': '[MeterChild]'},
        'sum_meter_groups': {'key': 'sumMeterGroups', 'type': '[MeterGroupChild]'},
    }

    def __init__(self, **kwargs):
        super(SumResponse, self).__init__(**kwargs)
        self.sum_meters = kwargs.get('sum_meters', None)
        self.sum_meter_groups = kwargs.get('sum_meter_groups', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagIssueTypeChild(Model):
    """FlagIssueTypeChild.

    :param flag_issue_type_id: The flag issue type identifier
    :type flag_issue_type_id: int
    :param flag_issue_type_info: Flag issue info
    :type flag_issue_type_info: str
    :param flag_issue_type_description: More detailed description of the flag
     issue type
    :type flag_issue_type_description: str
    :param flag_issue_category: Flag issue category
    :type flag_issue_category: str
    """

    _attribute_map = {
        'flag_issue_type_id': {'key': 'flagIssueTypeId', 'type': 'int'},
        'flag_issue_type_info': {'key': 'flagIssueTypeInfo', 'type': 'str'},
        'flag_issue_type_description': {'key': 'flagIssueTypeDescription', 'type': 'str'},
        'flag_issue_category': {'key': 'flagIssueCategory', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(FlagIssueTypeChild, self).__init__(**kwargs)
        self.flag_issue_type_id = kwargs.get('flag_issue_type_id', None)
        self.flag_issue_type_info = kwargs.get('flag_issue_type_info', None)
        self.flag_issue_type_description = kwargs.get('flag_issue_type_description', None)
        self.flag_issue_category = kwargs.get('flag_issue_category', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdminSettingsRequest(Model):
    """AdminSettingsRequest.

    All required parameters must be populated in order to send to Azure.

    :param field_name: Required. The setting field <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type field_name: str
    :param value: The setting value <span class='property-internal'>Must be
     between 0 and 255 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type value: str
    :param data_type_id: Required. The setting's data type identifier.
     Possible value include 1 (boolean), 2 (integer), 3 (string), 4 (double), 6
     (date) <span class='property-internal'>Required</span> <span
     class='property-internal'>One of 1, 2, 3, 4, 6 </span>
    :type data_type_id: int
    """

    _validation = {
        'field_name': {'required': True, 'max_length': 32, 'min_length': 0},
        'value': {'max_length': 255, 'min_length': 0},
        'data_type_id': {'required': True},
    }

    _attribute_map = {
        'field_name': {'key': 'fieldName', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'data_type_id': {'key': 'dataTypeId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AdminSettingsRequest, self).__init__(**kwargs)
        self.field_name = kwargs.get('field_name', None)
        self.value = kwargs.get('value', None)
        self.data_type_id = kwargs.get('data_type_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportCategoryChild(Model):
    """ReportCategoryChild.

    :param report_category_id:
    :type report_category_id: int
    :param report_category_code:
    :type report_category_code: str
    :param report_category_info:
    :type report_category_info: str
    """

    _attribute_map = {
        'report_category_id': {'key': 'reportCategoryId', 'type': 'int'},
        'report_category_code': {'key': 'reportCategoryCode', 'type': 'str'},
        'report_category_info': {'key': 'reportCategoryInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ReportCategoryChild, self).__init__(**kwargs)
        self.report_category_id = kwargs.get('report_category_id', None)
        self.report_category_code = kwargs.get('report_category_code', None)
        self.report_category_info = kwargs.get('report_category_info', None)
